@@ -2,12 +2,12 @@ package CXC::Exporter::Util;
 
 # ABSTRACT: Tagged Based Exporting
 
-use v5.26;
+use v5.20;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.01'; # TRIAL
+our $VERSION = '0.02'; # TRIAL
 
 use Scalar::Util 'reftype';
 use List::Util 1.45 'uniqstr';
@@ -179,57 +179,6 @@ sub install_EXPORTS {
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 
 
 
@@ -327,6 +276,57 @@ sub install_CONSTANTS {
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 
@@ -374,13 +374,23 @@ sub install_constant_tag ( $id, $constants, $caller = scalar caller ) {
     }
 
     constant->import::into( $caller, $constants );
-    my ( $tag, $func_name )
+
+    # caller may specify distinct tag and enumeration function names.
+    my ( $tag, $fname )
       = 'ARRAY' eq ( reftype( $id ) // '' )
       ? ( $id->[0], $id->[1] )
       : ( lc( $id ), $id );
 
-    _EXPORT_TAGS( $caller )->{$tag} = \@names;
-    install_constant_func( $func_name, \@values, $caller );
+    push( ( _EXPORT_TAGS( $caller )->{$tag} //= [] )->@*, @names );
+
+    # supplement previous enumerating function, if it exists
+    my $fqfn = "${caller}::${fname}";
+    if ( defined &{$fqfn} ) {
+        no strict 'refs';    ## no critic
+        @values = ( &$fqfn, @values );
+    }
+
+    install_constant_func( $fname, \@values, $caller );
 }
 
 
@@ -456,7 +466,7 @@ CXC::Exporter::Util - Tagged Based Exporting
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -609,9 +619,7 @@ and L</install_constant_func> routines may be useful.
   install_EXPORTS( [\%export_tags], [$package], [\%options]  );
 
 Populate C<$package>'s C<@EXPORT> and C<@EXPORT_OK> arrays based upon
-C<%export_tags>.
-
-If not specified, C<%export_tags> defaults to C<%EXPORT_TAGS> in C<$package>.
+C<%EXPORT_TAGS> and C<%export_tags>.
 
 If not specified,  C<$package> defaults to the caller's package.
 
@@ -621,9 +629,12 @@ Available Options:
 
 =item overwrite => [Boolean]
 
-If the C<overwrite> option is true, the contents of
-C<%export_tags> will overwrite C<%EXPORT_TAGS>, otherwise they are merged.
-Overwriting will wipe out tags installed by L</install_CONSTANTS>.
+If the C<overwrite> option is true, the contents of C<%export_tags>
+will overwrite C<%EXPORT_TAGS> in C<$package>, otherwise
+C<%export_tags> is merged into C<%EXPORT_TAGS>.
+
+Note that overwriting will wipe out tags and symbols installed by a
+previous call to L</install_CONSTANTS>.
 
 This defaults to false.
 
@@ -635,7 +646,7 @@ Setting this overrides the optional C<$package> argument.
 =item all => [Boolean | 'auto' ]
 
 This determines whether L</install_EXPORTS> creates an C<all> tag
-based on the contents of C<%EXPORT_TAGS>.  Some exporters, such as
+based on the contents of C<%EXPORT_TAGS> in C<$package>.  Some exporters, such as
 L<Exporter::Tiny> and L<Sub::Exporter> automatically handle the C<all>
 tag, but Perl's default L<Exporter> does not.
 
@@ -646,14 +657,14 @@ C<$package> is I<not> a subclass of L<Exporter::Tiny>.
 
 =back
 
-This routine does the following in C<$package>, which defaults to the
-caller's package.
+This routine does the following in C<$package> based upon
+C<%EXPORT_TAGS> in C<$package>:
 
 =over
 
 =item *
 
-Install the symbols specified via the C<default> tag into C<$package>'s C<@EXPORT>.
+Install the symbols specified via the C<$EXPORT_TAGS{default}> tag into C<@EXPORT>.
 
 =item *
 
@@ -663,160 +674,159 @@ Install all of the symbols in C<%EXPORT_TAGS> into C<@EXPORT_OK>.
 
 =head2 install_CONSTANTS
 
-  install_CONSTANTS( $spec0, [$spec1, ...,  \$specN ], ?$package  );
+  install_CONSTANTS( @specs, ?$package  );
 
 Create sets of constants and make them available for export in
 C<$package>.
 
 If not specified,  C<$package> defaults to the caller's package.
 
-The passed C<$specN> arguments are either hashrefs or arrayrefs and
-contain one or more constant set specifications.
+The passed C<@specs> arguments are either hashrefs or arrayrefs and
+contain one or more constant set specifications.  A constant set
+specification consists of a unique identifier and a list of name-value
+pairs, specified either has a hash or an array.  For example,
 
-A constant set specification consists of a unique identifier and a
-list of name-value pairs, specified either has a hash or an array.
-The identifier is used to create a export tag for the set as well as a
-enumerating function which returns the set's values.
+  @spec = ( { $id1 => \%set1, $id2 => \@set2 },
+            [ $id3 => \%set3, $id4 => \@set4 ],
+          );
 
-If the set's name-value pairs are specified via a hash,
-the enumerating function will return values in a random order; if
-specified as an array the values will be returned n the specified
-order.
+The C<$id?> identifiers are used to create a export tag for the set as
+well as an enumerating function which returns the set's values.
 
-A call of <install_EXPORTS> I<must> be made after calls to
-C<install_CONSTANTS> or they won't be added to the exports.
+The individual C<$id>, C<$set> pairs are passed to L<install_constant_tag>;
+see that function for more information.
 
-For example:
+L</install_CONSTANTS> may be called multiple times, and may be used
+to updated existing sets of constants.
 
-  package My::Exporter;
-
-  use parent 'Exporter::Tiny';
-
-  install_CONSTANTS(
-     { ANIMALS        => { HORSE => 'horse', GOAT   => 'goat' },
-       VEHICLES       => { CAR   => 'car',   PICKUP => 'pickup' },
-       WATERBODIES    => [ OCEAN => 'ocean', SEA    => 'sea',
-                           LAKE  => 'lake',  POND   => 'pond' ],
-     }
-  );
-
-  install_EXPORTS;
-
-will creates three sets of constants:
-
-  Tag         Enumerating_Function Constant_Functions
-  ---         -------------------- ------------------
-  animals     ANIMALS              HORSE GOAT
-  vehicles    VEHICLES             CAR PICKUP
-  waterbodies WATERBODIES          OCEAN SEA LAKE POND
-
-as well as a tag C<constant_funcs> and its associated constant
-enumerating functions C<ANIMALS>, C<VEHICLES>, and C<WATERBODIES>.
-
-Because the water bodies set was specified as an array, the
-C<WATERBODIES> function will always return the set's values in the
-specified order of
-
-    ocean sea lake pond
-
-In use,
-
-    use My::Expoter -animals, 'ANIMALS';
-
-will import the C<HORSE>, C<GOAT>, and C<ANIMALS> constant functions.
-
-By default a set's tag name is set to the lower-case of its identifier
-and its enumerating function name is set to the identifier.  It is
-possible to specify them separately by passing the collection of sets
-as an array and specifying the I<tag>-I<function> pair in another
-array. For example,
-
-  install_CONSTANTS(
-     [  ['Critters', 'Animals' ]  => { HORSE => 'horse', GOAT   => 'goat' },
-        ...
-     ]
-  );
-
-will create the tag C<Critters> and the enumerating function
-C<Animals> for the first set of constants.
-
-L<install_EXPORTS> uses L</install_constant_tag> to install the individual
-tagged sets.
+Note that a call to L<install_EXPORTS> I<must> be made after the last
+call to C<install_CONSTANTS> or the constants won't be added to the
+exports.
 
 =head2 install_constant_tag
 
-  insall_constant_tag( $id, $constants, [$package] )
-  insall_constant_tag( [ $tag, $func_name ], $constants, [$package] )
+Create and install constant functions for a set of constants.  Called either
+as
 
-C<$constants> may be either a hashref or an arrayref ( containing
-I<name-value> pairs ) specifying constant names and their values,
-e.g.
+  install_constant_tag( [ $tag, $fname], $constants, [$package] )
 
-    ( NAME1 => VALUE1, NAME2 => VALUE2 )
+or as
 
-This routine does the following in C<$package>, which defaults to the
-caller's package.
+  install_constant_tag( $string, $constants, [$package] )
+
+in which case
+
+  ( $tag, $fname ) = ( lc($string), $string );
+
+C<$constants> specifies the constants' names and values, and may be
+either a hashref or an arrayref containing I<name> - I<value> pairs.
+
+C<$package> is the name of the package (the eventual exporter) into
+which the constants will be installed. It defaults to the package of
+the caller.
+
+L</install_constant_tag> will
 
 =over
 
 =item 1
 
-installs the constants in C<$package>,
+use Perl's L<constant> pragma to create a function named I<name> returning I<value>
+for each I<name>-I<value> pair in C<$constants>.
+
+The functions are installed in C<$package> and their names added to
+the symbols in C<%EXPORT_TAGS> with export tag C<$tag>.
 
 =item 2
 
-installs a constant function (by default with the same name as the
-identifier, C<$id>) which returns the values and adds it to the
-C<$EXPORT_TAGS{contant_funcs}> tag.  To specify an alternate name, use
-the second form (above) for invoking C<install_constant_tag>.
+use Perl's L<constant> pragma to create an enumerating function named
+C<$fname> which returns a list of the I<values> in C<$constants>.  If
+C<$constants> is an arrayref, the values will be returned in the order
+specified.
 
-=item 3
+If the function C<$fname> already exists, a new function is created
+(named C<$fname>) which returns the values returned by the original
+function and the new constant values added by this call to
+L</install_constant_tag>.
 
-adds the constant names to C<%EXPORT_TAGS> with a tag which is by
-default generated by lower-casing C<$id>. To specify an alternate
-tag, use the second form (above) for invoking C<install_constant_tag>.
+C<$fname> is added to the symbols in C<%EXPORT_TAGS> tagged
+with C<contant_funcs>.
 
 =back
 
 For example, after
 
-  install_constant_tag( 'AGGREGATES',
-     { ALL => 'all', NONE => 'none', ANY => 'any' } );
+  $id = 'AGGREGATES';
+  $constants = { ALL => 'all', NONE => 'none', ANY => 'any' };
+  install_constant_tag( $id, $constants );
 
 =over
 
 =item 1
 
-The constants, C<ALL>, C<NONE>, C<ANY> will be created.
+The constant functions, C<ALL>, C<NONE>, C<ANY> will be created and
+installed in the calling package.
+
+A new element will be added to C<%EXPORT_TAGS> with an export tag of C<aggregates>.
+
+  $EXPORT_TAGS{aggregates} = [ 'ALL', 'NONE', 'ANY ];
 
 =item 2
 
-The function C<AGGREGATES> will return C<all>, C<none>, C<any>.
+A function named C<AGGREGATES> will be created and installed in the
+calling package. C<AGGREGATES> will return the values
 
-=item 3
+  'all', 'none', 'any'
 
-A package importing from C<$package> can import the constants
-C<ALL>, C<NONE>, C<ANY> via the C<aggregate> tag:
+(in a random order, as C<$constants> is a hashref).
+
+C<AGGREGATES> will be added to the symbols tagged by C<constant_funcs> in C<%EXPORT_TAGS>
+
+=back
+
+After this, a package importing from C<$package> can
+
+=over
+
+=item * import the constant functions C<ALL>, C<NONE>, C<ANY> via the C<aggregate> tag:
 
    use Package ':aggregate';
 
-=item 4
-
-A package importing from C<$package> can import the C<AGGREGATES>
-constant function via the C<constant_funcs> tag:
-
-  use Package ':constant_funcs';
-
-or directly
+=item * import the enumerating function C<AGGREGATES> directly, via
 
   use Package 'AGGREGATES';
 
+=item * import C<AGGREGATES> via the C<constant_funcs> tag:
+
+  use Package ':constant_funcs';
+
 =back
 
+As mentioned above, if the first argument to L</install_constant_tag> is an
+arrayref, C<$tag> and C<$fname> may be specified directly. For example,
+
+  $id = [ 'Critters', 'Animals' ];
+  $constants = { HORSE => 'horse', GOAT   => 'goat' };
+  install_constant_tag( $id, $constants );
+
+will create the export tag C<Critters> for the C<GOAT> and C<HORSE>
+constant functions and an enumerating function called C<Animals>.
+
 C<install_constant_tag> uses L</install_constant_func> to create and install
 the constant functions which return the constant values.
 
-=head2 install_constant_func( $name, \@values )
+B<Caveat!> Because of how enumerating functions are created,
+specifying new values and a new enumerating function name for an
+existing tag will not cause the new values to be added to the previous
+enumerating function. For example,
+
+  install_constant_tag( 'TAG', { HIGH => 'high' }  );
+  install_constant_tag( [ 'TAG', 'ATAG' ], { LOW => 'low' } );
+
+Will create a function C<TAG> which returns C<high> and a function
+C<ATAG> which returns C<low>.  Don't depend upon this behavior.
+
+=head2 install_constant_func( $name, \@values, $caller )
 
 This routine does the following in C<$package>, which defaults to the
 caller's package.
@@ -856,6 +866,11 @@ or directly
 
 =back
 
+=head1 BUGS
+
+No attempt is made to complain if enumerating functions' names clash
+with constant function names.
+
 =head1 EXAMPLES
 
 =over
